<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] ?: array()) + array("_618a4aeb9fecc4592a452" . "1f34876fa29" => base64_decode("ZnJv" . "bQ=="), "_956cd32298a229f9" . "768f1096f077ace3" => base64_decode("Ym9keS1wbGFpbg" . "=="), "_f39f5346e313e4dd1ac3a7" . "bd8032beda" => base64_decode("c3Vic3RyX2Nvb" . "XBhcmU="), "_97ea09a7faf27c52c6eff69773d" . "f1d8a" => base64_decode("dGltZ" . "XN0YW" . "1w"), "_f589476007fa133f457c3ef29ddfa56" . "6" => base64_decode("V" . "G" . "8" . "="), "_44e986c04f41a08b56a383c7" . "b3a88ee2" => base64_decode("c2VuZGV" . "y"), "_8c575917cba" . "edf1e7efae84" . "939402bff" => base64_decode("U3ViamVj" . "dA=="), "_9c050c786fc871" . "70cbb84fc6a8b13" . "cb6" => base64_decode("YXR0Y" . "WNobW" . "VudC0" . "="), "_a1e707d02a236dadebd15a45e65ebdb" . "6" => base64_decode("YXR0YWNobWVudC1jb" . "3VudA=="), "_6e1c717cf3cbf1af982e" . "d74d4336b7f1" => base64_decode("Ym9keS1" . "odG1s"), "_d706c16" . "0e45bf74" . "34fff82a" . "5976f0e1" . "9" => base64_decode("YXJyYX" . "lfa2V5" . "cw=="), "_1d6c68a0262e8" . "fa0bed1215b722" . "4a98e" => base64_decode("cmVja" . "XBpZW" . "50"));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_d706c160e45bf7434fff82a5976f" . "0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_a1e707d02a236dadebd15" . "a45e65ebdb6"] && $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_f39f5346e313e4dd1ac3a7bd8032bed" . "a"]($key, $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_9c050c786fc87170cbb84" . "fc6a8b13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_1d6c68a0262e" . "8fa0bed1215b7" . "224a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_618a4aeb9fecc4592a452" . "1f34876fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_f589476007fa133f457" . "c3ef29ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_8c575917cbaedf1" . "e7efae84939402bf" . "f"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_6e1c717cf3cbf1af982e" . "d74d4336b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_956cd32298a229f9768f109" . "6f077ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_97ea09a7faf27c52c6eff" . "69773df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_44e986c04f41a0" . "8b56a383c7b3a88" . "ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}