<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] ?: array()) + array("_bfda889b74e" . "a561b14325e3" . "0e7d75426" => base64_decode("Ym9keV9odG" . "1s"), "_a3d82c5df38e194c" . "9c73e3ccb4223bbc" => base64_decode("ZW1haW" . "xfZGF0" . "YQ=="), "_460e1aeb3113a1676ce59a8" . "f40431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3" . "MgZW1haWwgZm9yIGluZm9j" . "YXB0dXJlIHByb2plY3Q="), "_376d30c4085735" . "7a4d4cbb1ffaa25" . "817" => base64_decode("dG8" . "="), "_c35473364" . "fa7a050299" . "058f332ec2" . "9c1" => base64_decode("ZXhjZXB0aW" . "9u"), "_5d40a2cf1c525fb252bf5" . "599e339fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaWRlbnRpZmllZCBmb3" . "IgbWFpbDsgc3ViamVjdCAn"), "_9b16fa2683095e67d7c8b265a8081d" . "0b" => base64_decode("TWFpbFJlY2VpdmVkRXZlbnRSZWNla" . "XZlcg=="), "_ced92d7b391285c8a26846f1f4bd31" . "28" => base64_decode("Ym9keV90ZX" . "h0"), "_67a0d624aebcceb0abd" . "5ce56a53ff06f" => base64_decode("ZGF0Z" . "Q=="), "_618a4aeb9fecc4592a" . "4521f34876fa29" => base64_decode("ZnJv" . "bQ=="), "_e608e5b5c4c34a67" . "ba97ef84c1e16199" => base64_decode("Jw=" . "="), "proje" . "ct_id" => base64_decode("cHJvamVjdF9pZA" . "=="), "_f656816961e8573806141c" . "558b184fe2" => base64_decode("c3ViamVjdA" . "=="), "_03b1f0cee835582d1158dce2678" . "b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUgbWFpbC" . "ByZWNlaXZlZCBzdWJzY3JpYmVy"));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_9b16fa2683095e67d7c8b2" . "65a8081d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_03b1f0cee83558" . "2d1158dce2678b5" . "05c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_5d40a2cf1c525fb252bf5599e33" . "9fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_e608e5b5c4c34a67ba97ef" . "84c1e16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_618a4aeb9fecc4592a4" . "521f34876fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_376d30c40857357a4d4cbb1" . "ffaa25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_f656816961e8573806141c558b184fe" . "2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_ced92d7b391285c8a26846" . "f1f4bd3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_bfda889b74ea561b14325e30e" . "7d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_67a0d624aebcceb0abd5ce56a53f" . "f06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_460e1aeb3113a1676ce59a8f40431" . "d5c"], [$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["project" . "_id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_a3d82c5df38e194c9c73e3ccb42" . "23bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_c35473364fa7a05" . "0299058f332ec29c" . "1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}